==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/vmwarecloudsimple/kotlin/inputs/GuestOSNICCustomizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.vmwarecloudsimple.kotlin.inputs

import com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSNICCustomizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Guest OS nic customization
 * @property allocation IP address allocation method
 * @property dnsServers List of dns servers to use
 * @property gateway Gateway addresses assigned to nic
 * @property ipAddress Static ip address for nic
 * @property mask Network mask for nic
 * @property primaryWinsServer primary WINS server for Windows
 * @property secondaryWinsServer secondary WINS server for Windows
 */
public data class GuestOSNICCustomizationArgs(
    public val allocation: Output<String>? = null,
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<List<String>>? = null,
    public val ipAddress: Output<String>? = null,
    public val mask: Output<String>? = null,
    public val primaryWinsServer: Output<String>? = null,
    public val secondaryWinsServer: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSNICCustomizationArgs> {
    override fun toJava(): com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSNICCustomizationArgs =
        com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSNICCustomizationArgs.builder()
            .allocation(allocation?.applyValue({ args0 -> args0 }))
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ipAddress(ipAddress?.applyValue({ args0 -> args0 }))
            .mask(mask?.applyValue({ args0 -> args0 }))
            .primaryWinsServer(primaryWinsServer?.applyValue({ args0 -> args0 }))
            .secondaryWinsServer(secondaryWinsServer?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestOSNICCustomizationArgs].
 */
@PulumiTagMarker
public class GuestOSNICCustomizationArgsBuilder internal constructor() {
    private var allocation: Output<String>? = null

    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<List<String>>? = null

    private var ipAddress: Output<String>? = null

    private var mask: Output<String>? = null

    private var primaryWinsServer: Output<String>? = null

    private var secondaryWinsServer: Output<String>? = null

    /**
     * @param value IP address allocation method
     */
    @JvmName("ndhjyarxjtwehyte")
    public suspend fun allocation(`value`: Output<String>) {
        this.allocation = value
    }

    /**
     * @param value List of dns servers to use
     */
    @JvmName("fhgoklssrvepnbje")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("mallewkgfaajyayi")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values List of dns servers to use
     */
    @JvmName("ubwwrfrhouwbnprs")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Gateway addresses assigned to nic
     */
    @JvmName("pdxhotpwyljffxir")
    public suspend fun gateway(`value`: Output<List<String>>) {
        this.gateway = value
    }

    @JvmName("junoffnbhomkrwuu")
    public suspend fun gateway(vararg values: Output<String>) {
        this.gateway = Output.all(values.asList())
    }

    /**
     * @param values Gateway addresses assigned to nic
     */
    @JvmName("dijeydqdsgotvitu")
    public suspend fun gateway(values: List<Output<String>>) {
        this.gateway = Output.all(values)
    }

    /**
     * @param value Static ip address for nic
     */
    @JvmName("uslojqlvnbwvnfji")
    public suspend fun ipAddress(`value`: Output<String>) {
        this.ipAddress = value
    }

    /**
     * @param value Network mask for nic
     */
    @JvmName("mjyqvommuippmvpr")
    public suspend fun mask(`value`: Output<String>) {
        this.mask = value
    }

    /**
     * @param value primary WINS server for Windows
     */
    @JvmName("amrsknqvcwkwmxpa")
    public suspend fun primaryWinsServer(`value`: Output<String>) {
        this.primaryWinsServer = value
    }

    /**
     * @param value secondary WINS server for Windows
     */
    @JvmName("xrbuteqnhxpwjesf")
    public suspend fun secondaryWinsServer(`value`: Output<String>) {
        this.secondaryWinsServer = value
    }

    /**
     * @param value IP address allocation method
     */
    @JvmName("xmwfgwteaeldubhl")
    public suspend fun allocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allocation = mapped
    }

    /**
     * @param value List of dns servers to use
     */
    @JvmName("lknvfeksoltcgvye")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values List of dns servers to use
     */
    @JvmName("krwqwpwlkwadfgde")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Gateway addresses assigned to nic
     */
    @JvmName("aqhnqovlikleruye")
    public suspend fun gateway(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param values Gateway addresses assigned to nic
     */
    @JvmName("wuyjmdigghwgfcgb")
    public suspend fun gateway(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value Static ip address for nic
     */
    @JvmName("hqcgtwfkwhmdodtw")
    public suspend fun ipAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddress = mapped
    }

    /**
     * @param value Network mask for nic
     */
    @JvmName("lirjkipwhikvraxq")
    public suspend fun mask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mask = mapped
    }

    /**
     * @param value primary WINS server for Windows
     */
    @JvmName("bwqaptdloblkfhml")
    public suspend fun primaryWinsServer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryWinsServer = mapped
    }

    /**
     * @param value secondary WINS server for Windows
     */
    @JvmName("oaroanuftqbhpkoy")
    public suspend fun secondaryWinsServer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryWinsServer = mapped
    }

    internal fun build(): GuestOSNICCustomizationArgs = GuestOSNICCustomizationArgs(
        allocation = allocation,
        dnsServers = dnsServers,
        gateway = gateway,
        ipAddress = ipAddress,
        mask = mask,
        primaryWinsServer = primaryWinsServer,
        secondaryWinsServer = secondaryWinsServer,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/vmwarecloudsimple/kotlin/inputs/GuestOSNICCustomizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.vmwarecloudsimple.kotlin.inputs

import com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSNICCustomizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Guest OS nic customization
 * @property allocation IP address allocation method
 * @property dnsServers List of dns servers to use
 * @property gateway Gateway addresses assigned to nic
 * @property ipAddress Static ip address for nic
 * @property mask Network mask for nic
 * @property primaryWinsServer primary WINS server for Windows
 * @property secondaryWinsServer secondary WINS server for Windows
 */
public data class GuestOSNICCustomizationArgs(
    public val allocation: Output<String>? = null,
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<List<String>>? = null,
    public val ipAddress: Output<String>? = null,
    public val mask: Output<String>? = null,
    public val primaryWinsServer: Output<String>? = null,
    public val secondaryWinsServer: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSNICCustomizationArgs> {
    override fun toJava(): com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSNICCustomizationArgs =
        com.pulumi.azurenative.vmwarecloudsimple.inputs.GuestOSNICCustomizationArgs.builder()
            .allocation(allocation?.applyValue({ args0 -> args0 }))
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ipAddress(ipAddress?.applyValue({ args0 -> args0 }))
            .mask(mask?.applyValue({ args0 -> args0 }))
            .primaryWinsServer(primaryWinsServer?.applyValue({ args0 -> args0 }))
            .secondaryWinsServer(secondaryWinsServer?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestOSNICCustomizationArgs].
 */
@PulumiTagMarker
public class GuestOSNICCustomizationArgsBuilder internal constructor() {
    private var allocation: Output<String>? = null

    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<List<String>>? = null

    private var ipAddress: Output<String>? = null

    private var mask: Output<String>? = null

    private var primaryWinsServer: Output<String>? = null

    private var secondaryWinsServer: Output<String>? = null

    /**
     * @param value IP address allocation method
     */
    @JvmName("noeiqgkakaclowfw")
    public suspend fun allocation(`value`: Output<String>) {
        this.allocation = value
    }

    /**
     * @param value List of dns servers to use
     */
    @JvmName("bsucgarlolvmdtgx")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("aycddpauvspxojls")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values List of dns servers to use
     */
    @JvmName("lcoksvtfstdjdscd")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Gateway addresses assigned to nic
     */
    @JvmName("vnythewammnyhgly")
    public suspend fun gateway(`value`: Output<List<String>>) {
        this.gateway = value
    }

    @JvmName("pyvkistslcovdwtr")
    public suspend fun gateway(vararg values: Output<String>) {
        this.gateway = Output.all(values.asList())
    }

    /**
     * @param values Gateway addresses assigned to nic
     */
    @JvmName("pirtrhkpipyehggc")
    public suspend fun gateway(values: List<Output<String>>) {
        this.gateway = Output.all(values)
    }

    /**
     * @param value Static ip address for nic
     */
    @JvmName("gurhbfeiderchxpp")
    public suspend fun ipAddress(`value`: Output<String>) {
        this.ipAddress = value
    }

    /**
     * @param value Network mask for nic
     */
    @JvmName("cpowhpitbcnsvwwg")
    public suspend fun mask(`value`: Output<String>) {
        this.mask = value
    }

    /**
     * @param value primary WINS server for Windows
     */
    @JvmName("vayfgpcysnlejshs")
    public suspend fun primaryWinsServer(`value`: Output<String>) {
        this.primaryWinsServer = value
    }

    /**
     * @param value secondary WINS server for Windows
     */
    @JvmName("bejtcixqbntjxida")
    public suspend fun secondaryWinsServer(`value`: Output<String>) {
        this.secondaryWinsServer = value
    }

    /**
     * @param value IP address allocation method
     */
    @JvmName("kkjeufsxxejrsuut")
    public suspend fun allocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allocation = mapped
    }

    /**
     * @param value List of dns servers to use
     */
    @JvmName("kditiwbkxngtqlun")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values List of dns servers to use
     */
    @JvmName("cngwvxjwcoxkubho")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Gateway addresses assigned to nic
     */
    @JvmName("wnlirkidekgtovbg")
    public suspend fun gateway(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param values Gateway addresses assigned to nic
     */
    @JvmName("qtauhpmgixovceeo")
    public suspend fun gateway(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value Static ip address for nic
     */
    @JvmName("iuiirlktbqujgnat")
    public suspend fun ipAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddress = mapped
    }

    /**
     * @param value Network mask for nic
     */
    @JvmName("ladbubxoynemrifw")
    public suspend fun mask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mask = mapped
    }

    /**
     * @param value primary WINS server for Windows
     */
    @JvmName("lluubnanancywqgc")
    public suspend fun primaryWinsServer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryWinsServer = mapped
    }

    /**
     * @param value secondary WINS server for Windows
     */
    @JvmName("xdysfvafhydnkeap")
    public suspend fun secondaryWinsServer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryWinsServer = mapped
    }

    internal fun build(): GuestOSNICCustomizationArgs = GuestOSNICCustomizationArgs(
        allocation = allocation,
        dnsServers = dnsServers,
        gateway = gateway,
        ipAddress = ipAddress,
        mask = mask,
        primaryWinsServer = primaryWinsServer,
        secondaryWinsServer = secondaryWinsServer,
    )
}
